Communication primitives
========================

allgather
---------

.. autofunction:: mpi4jax.allgather

allreduce
---------

.. autofunction:: mpi4jax.allreduce

alltoall
--------

.. autofunction:: mpi4jax.alltoall

bcast
-----

.. autofunction:: mpi4jax.bcast

gather
------

.. autofunction:: mpi4jax.gather

recv
----

.. autofunction:: mpi4jax.recv

reduce
------

.. autofunction:: mpi4jax.reduce

scan
----

.. autofunction:: mpi4jax.scan

scatter
-------

.. autofunction:: mpi4jax.scatter

send
----

.. autofunction:: mpi4jax.send

sendrecv
--------

.. autofunction:: mpi4jax.sendrecv
